Learn R Programming

abstr (version 0.4.2)

montlake_buildings: Example OSM Buildings Table for Montlake

Description

Each row of this table contains a building that exists within a zone in the montlake_zones table.

Arguments

Format

A sf dataframe with columns:

osm_way_id

OSM ID assigned to each building.

name

OSM name assigned to each building (might be NA).

building

OSM building category assigned to each building.

geometry

Simple feature collection (sfc) contain multipolygons, each representing the boundaries of a building.

Details

These buildings were retrieved using osmextract::oe_read(). See the code used to create this data in data-raw/montlake-test-data.R.

Examples

Run this code
library(sf)
names(montlake_buildings)
head(montlake_buildings$osm_way_id)
head(montlake_buildings$name)
head(montlake_buildings$building)
nrow(montlake_buildings)
plot(montlake_buildings)

Run the code above in your browser using DataLab