powered by
Each row of this table contains a building that exists within a zone in the montlake_zones table.
montlake_zones
A sf dataframe with columns:
OSM ID assigned to each building.
OSM name assigned to each building (might be NA).
OSM building category assigned to each building.
Simple feature collection (sfc) contain multipolygons, each representing the boundaries of a building.
These buildings were retrieved using osmextract::oe_read(). See the code used to create this data in data-raw/montlake-test-data.R.
osmextract::oe_read()
data-raw/montlake-test-data.R
library(sf) names(montlake_buildings) head(montlake_buildings$osm_way_id) head(montlake_buildings$name) head(montlake_buildings$building) nrow(montlake_buildings) plot(montlake_buildings)
Run the code above in your browser using DataLab