sao_paulo_activity_df_20: Example Activity data for São Paulo
Description
Each row of this table contains a single trip of people in the São Paulo city.
sao_paulo_activity_df_2 represents the movement of 2 people,
sao_paulo_activity_df_20 represents the movement of 20 people.
Usage
sao_paulo_activity_df_20
Arguments
Format
A data frame with columns:
ID_PESS
Person identifier.
CO_O_X
Origin coordinate X.
CO_O_Y
Origin coordinate Y.
CO_D_X
Destination coordinate X.
CO_D_Y
Destination coordinate Y.
MODOPRIN
Main mode.
H_SAIDA
Departure hour.
MIN_SAIDA
Departure minute.
Details
See the code used to create this data, and the full open dataset with
128 variables, the file
data-raw/sao-paulo-activity-data.R
in the package's GitHub repo.